@@ -400,7 +400,10 @@ class Media(object):
                 raise ValueError('Cannot delete for it is scheduled')
         elif schedule == {}:
             print("j'efface: {}".format(self.filepath))
-            os.remove(self.filepath)
+            if os.path.exists(self.filepath):
+                os.remove(self.filepath)
+            else:
+                print("{} n'existes pas".format(self.filepath))
         return
 
 
